[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [26621] trunk/blender/source/blender/ editors/space_view3d/drawarmature.c: Armature Drawing - Active Bone:

Joshua Leung aligorith at gmail.com
Fri Feb 5 12:39:58 CET 2010


Revision: 26621
          http://projects.blender.org/plugins/scmsvn/viewcvs.php?view=rev&root=bf-blender&revision=26621
Author:   aligorith
Date:     2010-02-05 12:39:58 +0100 (Fri, 05 Feb 2010)

Log Message:
-----------
Armature Drawing - Active Bone:

Active bones are now only highlighted if they are also selected. This reduces confusion over when something will get moved/edited.

Modified Paths:
--------------
    trunk/blender/source/blender/editors/space_view3d/drawarmature.c

Modified: trunk/blender/source/blender/editors/space_view3d/drawarmature.c
===================================================================
--- trunk/blender/source/blender/editors/space_view3d/drawarmature.c	2010-02-05 11:32:27 UTC (rev 26620)
+++ trunk/blender/source/blender/editors/space_view3d/drawarmature.c	2010-02-05 11:39:58 UTC (rev 26621)
@@ -1636,8 +1636,8 @@
 					if ( (bone->parent) && (bone->parent->flag & (BONE_HIDDEN_P|BONE_HIDDEN_PG)) )
 						flag &= ~BONE_CONNECTED;
 					
-					/* set temporary flag for drawing bone as active */
-					if (bone == arm->act_bone)
+					/* set temporary flag for drawing bone as active, but only if selected */
+					if ((bone == arm->act_bone) && (bone->flag & BONE_SELECTED))
 						flag |= BONE_DRAW_ACTIVE;
 					
 					/* set color-set to use */
@@ -1721,8 +1721,8 @@
 							if ((bone->parent) && (bone->parent->flag & (BONE_HIDDEN_P|BONE_HIDDEN_PG)))
 								flag &= ~BONE_CONNECTED;
 								
-							/* set temporary flag for drawing bone as active */
-							if (bone == arm->act_bone)
+							/* set temporary flag for drawing bone as active, but only if selected */
+							if ((bone == arm->act_bone) && (bone->flag & BONE_SELECTED))
 								flag |= BONE_DRAW_ACTIVE;
 							
 							draw_custom_bone(scene, v3d, rv3d, pchan->custom, OB_WIRE, arm->flag, flag, index, bone->length);
@@ -1816,8 +1816,8 @@
 					if ((bone->parent) && (bone->parent->flag & (BONE_HIDDEN_P|BONE_HIDDEN_PG)))
 						flag &= ~BONE_CONNECTED;
 					
-					/* set temporary flag for drawing bone as active */
-					if (bone == arm->act_bone)
+					/* set temporary flag for drawing bone as active, but only if selected */
+					if ((bone == arm->act_bone) && (bone->flag & BONE_SELECTED))
 						flag |= BONE_DRAW_ACTIVE;
 					
 					/* extra draw service for pose mode */
@@ -1980,8 +1980,8 @@
 					if ( (eBone->parent) && ((eBone->parent->flag & BONE_HIDDEN_A) || (eBone->parent->layer & arm->layer)==0) )
 						flag &= ~BONE_CONNECTED;
 						
-					/* set temporary flag for drawing bone as active */
-					if (eBone == arm->act_edbone)
+					/* set temporary flag for drawing bone as active, but only if selected */
+					if ((eBone == arm->act_edbone) && (eBone->flag & BONE_SELECTED))
 						flag |= BONE_DRAW_ACTIVE;
 					
 					if (arm->drawtype==ARM_ENVELOPE)
@@ -2019,8 +2019,8 @@
 				if ( (eBone->parent) && ((eBone->parent->flag & BONE_HIDDEN_A) || (eBone->parent->layer & arm->layer)==0) )
 					flag &= ~BONE_CONNECTED;
 					
-				/* set temporary flag for drawing bone as active */
-				if (eBone == arm->act_edbone)
+				/* set temporary flag for drawing bone as active, but only if selected */
+				if ((eBone == arm->act_edbone) && (eBone->flag & BONE_SELECTED))
 					flag |= BONE_DRAW_ACTIVE;
 				
 				if (arm->drawtype == ARM_ENVELOPE) {





More information about the Bf-blender-cvs mailing list